1.6.1 2018-09-06
================
----

* Add commonmark 0.8.1 compatibility

1.6.0 2017-12-03
================
----

* Now tested on Django 2.0


1.5.1 2016-12-07
================
----

* Feature #32: Upgrade CommonMark to latest version (0.7.2).


1.5
===
----

* Added tests for rendering code blocks.
* The code is now automatically being checked by flake8.
* Added compatibility with CommonMark-py 0.6.x.
* Dropped support for Python 3.3, added Python 3.5.


1.4 2015-04-26
==============
----

* Feature #18: Fix typo in ChangeLog.
* Feature #19: Force ``commonmark`` input to a string to prevent exception.
* Feature #20: Update gitignore to cover more Python stuff.
* Fix #21: Fix latest version of the package on PyPi.
* Update requirements/dev.txt to the latest.



1.3 2015-04-04
==============
----

* Feature #11: Correct capitalization / spacing for reStructuredText and docutils in ``README.rst``.
* Feature #12: PEP440 compliance with version number.
* Feature #14: Add ``commonmark`` filter.
* Feature #17: Add ``commonmark`` filter to ``README.rst``.
* Fix #15: Fix typos in run_tests.py
* New awesome contributors/authors joined the project.


2014.9.20 2014-09-20
====================
----

* Fix #9: Django package name typo.
* Feature: Add `AUTHORS.rst`` file.
* Feature: Reorganized ``requirements``.
* Feature: Runnning tests with ``tox``.
* Feature: Add support for ``Python3`` and ``PyPy``.
* Feature: Add ``wheel`` package support.
* Feature: Change version numbering to date based.
* Feature: Update ``Python-Markdown``, ``textile`` and ``docutils`` parser modules to latest.


1.1 2014-01-19
==============
----

* Added ChangeLog.rst
* Fixed #2: Removing backward compatibility, From markup.py.
* Fixed #1: Re-Indention and Re-Style the code regards to pep8.
* Fixed #7: Testing on travis-ci - https://travis-ci.org/Alir3z4/django-markwhat


1.0 2013-01-08
==============
----

* Initial version.

